[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
master c8e2881: Minor fixes for a recent commit
From: |
Eli Zaretskii |
Subject: |
master c8e2881: Minor fixes for a recent commit |
Date: |
Wed, 24 Nov 2021 09:20:00 -0500 (EST) |
branch: master
commit c8e28813af0ece36a78872c67f419cb0a0bbb6b9
Author: Eli Zaretskii <eliz@gnu.org>
Commit: Eli Zaretskii <eliz@gnu.org>
Minor fixes for a recent commit
* src/xdisp.c (find_display_property): Fix style of comments.
(Fget_display_property): Doc fix.
(get_display_property): Fix style and whitespace.
---
src/xdisp.c | 22 +++++++++++-----------
1 file changed, 11 insertions(+), 11 deletions(-)
diff --git a/src/xdisp.c b/src/xdisp.c
index cda7e04..5950941 100644
--- a/src/xdisp.c
+++ b/src/xdisp.c
@@ -5150,7 +5150,7 @@ find_display_property (Lisp_Object disp, Lisp_Object prop)
{
if (NILP (disp))
return Qnil;
- /* We have a vector of display specs. */
+ /* We have a vector of display specs. */
if (VECTORP (disp))
{
for (ptrdiff_t i = 0; i < ASIZE (disp); i++)
@@ -5163,7 +5163,7 @@ find_display_property (Lisp_Object disp, Lisp_Object prop)
}
return Qnil;
}
- /* We have a list of display specs. */
+ /* We have a list of display specs. */
else if (CONSP (disp)
&& CONSP (XCAR (disp)))
{
@@ -5176,7 +5176,7 @@ find_display_property (Lisp_Object disp, Lisp_Object prop)
return XCAR (XCDR (elem));
/* Check that we have a proper list before going to the next
- element. */
+ element. */
if (CONSP (XCDR (disp)))
disp = XCDR (disp);
else
@@ -5184,7 +5184,7 @@ find_display_property (Lisp_Object disp, Lisp_Object prop)
}
return Qnil;
}
- /* A simple display spec. */
+ /* A simple display spec. */
else if (CONSP (disp)
&& CONSP (XCDR (disp))
&& EQ (XCAR (disp), prop))
@@ -5193,11 +5193,11 @@ find_display_property (Lisp_Object disp, Lisp_Object
prop)
return Qnil;
}
-static Lisp_Object get_display_property (ptrdiff_t bufpos, Lisp_Object prop,
- Lisp_Object object)
+static
+Lisp_Object get_display_property (ptrdiff_t bufpos, Lisp_Object prop,
+ Lisp_Object object)
{
return find_display_property (Fget_text_property (make_fixnum (bufpos),
-
Qdisplay, object),
prop);
}
@@ -5282,12 +5282,12 @@ display_min_width (struct it *it, ptrdiff_t bufpos,
DEFUN ("get-display-property", Fget_display_property,
Sget_display_property, 2, 4, 0,
- doc: /* Get the `display' property PROP at POSITION.
+ doc: /* Get the value of the `display' property PROP at POSITION.
If OBJECT, this should be a buffer or string where the property is
-fetched from. This defaults to the current buffer.
+fetched from. If omitted, OBJECT defaults to the current buffer.
-If PROPERTIES, use those properties instead of the properties at
-POSITION. */)
+If PROPERTIES, look for value of PROP in PROPERTIES instead of the
+properties at POSITION. */)
(Lisp_Object position, Lisp_Object prop, Lisp_Object object,
Lisp_Object properties)
{
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- master c8e2881: Minor fixes for a recent commit,
Eli Zaretskii <=